<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {
	// This gets the theme name from the stylesheet
	$themename = 'retro';
	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'd5businessline'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	$options[] = array(
		'name' => 'Global', // tab title
		'type' => 'heading');
// Quotation
	$options[] = array(
		'desc' => '<span class="featured-area-title">Bottom Quotation</span>',
		'type' => 'info');
	
	$options[] = array(
		'name' => '', 
		'desc' => 'Uncheck this if you wish to hide quote.',
		'id' => 'bottom-quotation-show',
		'std' => "checked",
		'type' => 'checkbox');
	
	$options[] = array(
		'name' => 'Quote Text',
		'desc' => 'Input your Quotation here.',
		'id' => 'bottom-quotation',
		'std' => 'Only one thing is impossible for God: To find any sense in any copyright law on the planet.
		<div class="alignright"><a href="'.get_home_url().'">Mark Twain &raquo;</a></div>',
		'type' => 'textarea');
// Header
$options[] = array(
		'name' => 'Header',
		'type' => 'heading');

	$options[] = array(
		'name' => 'Logo',
		'desc' => 'Upload an image for the logo. PNG image is recommended.',
		'id' => 'logo',
		'std' => get_template_directory_uri() . '/images/logo.png',
		'type' => 'upload');
	
	$options[] = array(
		'desc' => '<span class="featured-area-title">Mini Buttons</span>',
		'type' => 'info');

	$options[] = array(
		'name' => 'RSS Link', 
		'desc' => 'Input your RSS URL here. eg: http://feeds2.feedburner.com/hiHelloo (default: '.get_bloginfo( 'rss2_url' ).')',
		'id' => 'h-rss',
		'std' => NULL,
		'type' => 'text');
	$options[] = array(
		'name' => 'Twitter', 
		'desc' => 'eg. https://twitter.com/username',
		'id' => 'h-t',
		'std' => NULL,
		'type' => 'text');
	$options[] = array(
		'name' => 'Facebbok', 
		'desc' => 'eg. https://www.facebook.com/username',
		'id' => 'h-f',
		'std' => NULL,
		'type' => 'text');
	$options[] = array(
		'name' => 'Contact', 
		'desc' => 'eg. '.get_home_url().'/hellooooo',
		'id' => 'h-mail',
		'std' => NULL,
		'type' => 'text');
// Front Page
$options[] = array(
		'name' => 'Front Page',
		'type' => 'heading');

	$options[] = array(
		'desc' => '<span class="featured-area-title">Slider Settings</span>',
		'type' => 'info');

	$options[] = array(
		'name' => '', 
		'desc' => 'Enable slider (Uncheck this if you wish to disable slider)',
		'id' => 'disable-slider',
		'std' => "checked",
		'type' => 'checkbox');
	
	$options[] = array(
		'name' => '', 
		'desc' => 'Slider width (max:620px)',
		'id' => 'slider-width',
		'std' => 620,
		'type' => 'text');
	$options[] = array(
		'name' => '', 
		'desc' => 'Slider height (default:320px)',
		'id' => 'slider-height',
		'std' => 320,
		'type' => 'text');
	$options[] = array(
		'name' => '', 
		'desc' => 'Slider animtype',
		'id' => 'slider-animtype',
		'options' => array("fade"=>"Fade","slide"=>"Slide"),
		'type' => 'select');
	$options[] = array(
		'name' => '', 
		'desc' => 'Slider Automatic(auto-start)',
		'id' => 'slider-automatic',
		'options' => array("true"=>"True","false"=>"False"),
		'type' => 'select');
	
	$options[] = array(
		'desc' => '<span class="featured-area-title">Control and marker configuration</span>',
		'type' => 'info');
	
	$options[] = array(
		'name' => '', 
		'desc' => 'show next and prev controls',
		'id' => 'slider-showcontrols',
		'options' => array("true"=>"True","false"=>"False"),
		'type' => 'select');
	$options[] = array(
		'name' => '', 
		'desc' => 'Text for "next" button',
		'id' => 'slider-nexttext',
		'std' => "Next",
		'type' => 'text');
	$options[] = array(
		'name' => '', 
		'desc' => 'Text for "previous" button',
		'id' => 'slider-prevtext',
		'std' => "Prev",
		'type' => 'text');
	$options[] = array(
		'name' => '', 
		'desc' => 'Show individual slide markers',
		'id' => 'slider-showmarkers',
		'options' => array("true"=>"True","false"=>"False"),
		'type' => 'select');
	$options[] = array(
		'name' => '', 
		'desc' => 'Slider main theme color',
		'id' => 'slider-color',
		'std' => "",
		'type' => 'color');
	
	
	$options[] = array(
		'name' => '', 
		'desc' => 'slider items count',
		'id' => 'slider-items-count',
		'std' => 3,
		'type' => 'text');
	
	$options[] = array(
		'desc' => '<span class="featured-area-title">Slider Items</span>',
		'type' => 'info');	
	// slider items
	$count = of_get_option('slider-items-count',3) +1;
	for ($i=1;$i<$count;$i++) {
		if ($i<=3) $image = get_template_directory_uri() . "/inc/slider/banner-$i.jpg";
		$options[] = array(
			'name' => "slider #$i",
			'desc' => "Upload an image for the slider #$i (height:320, width:620)",
			'id' => "slider-image-$i",
			'std' => $image,
			'type' => 'upload');
		$options[] = array(
			'name' => '', 
			'desc' => "Text for slider #$i",
			'id' => "slider-text-$i",
			'type' => 'text');
		$options[] = array(
			'name' => '', 
			'desc' => "URI for slider #$i",
			'id' => "slider-url-$i",
			'type' => 'text');
	}

// Social
	$options[] = array(
		'name' => 'Social',
		'type' => 'heading');

	$options[] = array(
		'desc' => '<span class="featured-area-title">Social Links</span>',
		'type' => 'info');


		// All services
		$list = array('aim','ask','bebo','betvibes','blinklist','blogger','buzz','delicious','deviantart','digg','diigo','everynote','facebook','flickr','friendfeed','friendster','furl','google','lastfm','linkedin','livejournal','mixx','myspace','newsvine','orkut','plaxo','plurk','posterous','reddit','rss','shoutwire','spurl','squidoo','stumbleupon','technorati','tumblr','twitter','vimeo','wordpress','xanga','yahoo','youtube');
		foreach ($list as $i) {
			$options[] = array(
				'name' => ucfirst($i),
				'desc' => "Input your <b>$i</b> url here.",
				'id' => $i,
				'std' => '',
				'type' => 'text');
		}

// Ads
	$options[] = array(
		'name' => 'Ads', // tab title
		'type' => 'heading');
	
	$options[] = array(
		'name' => 'Header 468x60',
		'desc' => 'Input your 468x60 ad code here.',
		'id' => 'ad-468x60',
		'std' => '
		<!-- start:ad.468x60 -->
		<a href="' .esc_url(home_url()). '" target="_blank">
		<img alt="" src="' . get_template_directory_uri() . '/images/468x60-Ad.gif" />
		</a>
		<!-- end:ad.468x60 -->',
		'type' => 'textarea');
	$options[] = array(
		'desc' => 'Example:<br /><img alt="" src="' . get_template_directory_uri() . '/images/468x60-Ad.gif" />',
		'type' => 'info');	

// Pro TAB
//	$options[] = array(
//		'name' => 'Get PRO!',
//		'type' => 'heading');
//	$options[] = array(
//		'desc' => 'Need more features and options? Try <a href="http://s.com/?15" target="_blank"><b>get</b></a>.',
//		'type' => 'info');
	return $options;
}

/*
 * This is an example of how to add custom scripts to the options panel.
 * This example shows/hides an option when a checkbox is clicked.
 */

add_action('optionsframework_custom_scripts', 'optionsframework_custom_scripts');

function optionsframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function($) {

	$('#example_showhidden').click(function() {
  		$('#section-example_text_hidden').fadeToggle(400);
	});

	if ($('#example_showhidden:checked').val() !== undefined) {
		$('#section-example_text_hidden').show();
	}

});
</script>

<?php
}